==> coupon-facade-2.0.0-20191211.114201-43-sources.jar: com/bizvane/couponfacade/models/vo/CouponSendAgainRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import com.bizvane.connectorservice.entity.common.CouponRequestVO;

/**
 * 补发券
 * Created by yunjie.tian on 2018/8/21.
 */
public class CouponSendAgainRequestVO extends CouponRequestVO{

    private String batchSendCode;

    private Long sysBrandId;

    private Long couponEntityId;

    private Long couponSendFailLogId;

    private Long couponDefinitionId;
    
	private Byte couponDefinitionType;

	
    public Byte getCouponDefinitionType() {
		return couponDefinitionType;
	}

	public void setCouponDefinitionType(Byte couponDefinitionType) {
		this.couponDefinitionType = couponDefinitionType;
	}

	public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public String getBatchSendCode() {
        return batchSendCode;
    }

    public void setBatchSendCode(String batchSendCode) {
        this.batchSendCode = batchSendCode;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getCouponEntityId() {
        return couponEntityId;
    }

    public void setCouponEntityId(Long couponEntityId) {
        this.couponEntityId = couponEntityId;
    }

    public Long getCouponSendFailLogId() {
        return couponSendFailLogId;
    }

    public void setCouponSendFailLogId(Long couponSendFailLogId) {
        this.couponSendFailLogId = couponSendFailLogId;
    }
}

==> coupon-facade-2.0.0-20200323.123007-72-sources.jar: com/bizvane/couponfacade/models/vo/CouponSendAgainRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import com.bizvane.connectorservice.entity.common.CouponRequestVO;

/**
 * 补发券
 * Created by yunjie.tian on 2018/8/21.
 */
public class CouponSendAgainRequestVO extends CouponRequestVO{

    private String batchSendCode;

    private Long sysBrandId;

    private Long couponEntityId;

    private Long couponSendFailLogId;

    private Long couponDefinitionId;
    
	private Byte couponDefinitionType;

    private String offlinePrdCode;
	
    public Byte getCouponDefinitionType() {
		return couponDefinitionType;
	}

	public void setCouponDefinitionType(Byte couponDefinitionType) {
		this.couponDefinitionType = couponDefinitionType;
	}

	public Long getCouponDefinitionId() {
        return couponDefinitionId;
    }

    public void setCouponDefinitionId(Long couponDefinitionId) {
        this.couponDefinitionId = couponDefinitionId;
    }

    public String getBatchSendCode() {
        return batchSendCode;
    }

    public void setBatchSendCode(String batchSendCode) {
        this.batchSendCode = batchSendCode;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getCouponEntityId() {
        return couponEntityId;
    }

    public void setCouponEntityId(Long couponEntityId) {
        this.couponEntityId = couponEntityId;
    }

    public Long getCouponSendFailLogId() {
        return couponSendFailLogId;
    }

    public void setCouponSendFailLogId(Long couponSendFailLogId) {
        this.couponSendFailLogId = couponSendFailLogId;
    }

    public String getOfflinePrdCode() {
        return offlinePrdCode;
    }

    public void setOfflinePrdCode(String offlinePrdCode) {
        this.offlinePrdCode = offlinePrdCode;
    }
}
